# Release Notes

---

## Upgrading

To upgrade `polyline-ruler` to the latest version, use pip:

```bash
pip install -U polyline-ruler
```

## Version 0.0.5 (2023-06-23)

*   Faster pointOnLine by lla2enu hard copy once

## Version 0.0.4 (2023-03-11)

*   Misc updates
    *   Update dir logic
    *   Integrate douglas_simplify iter

## Version 0.0.3 (2023-03-05)

*   Use GitHub workflow to release to pypi

## Version 0.0.2 (2023-01-19)

*   More bindings, more tests

## Version 0.0.1 (2022-10-08)

*   First release

---

You can also checkout releases on:

-   GitHub: <https://github.com/cubao/polyline-ruler/releases>
-   PyPi: <https://pypi.org/project/polyline-ruler>
